@@ -27,7 +27,7 @@ from praw.compat import (HTTPCookieProcessor,  # pylint: disable-msg=E0611
                          urljoin)
 from praw.settings import CONFIG
 
-__version__ = '1.0.8'
+__version__ = '1.0.9'
 UA_STRING = '%%s PRAW/%s Python/%s %s' % (__version__,
                                           sys.version.split()[0],
                                           platform.platform(True))
@@ -64,6 +64,7 @@ class Config(object):  # pylint: disable-msg=R0903
                  'my_mod_reddits':      'reddits/mine/moderator/',
                  'my_reddits':          'reddits/mine/',
                  'new':                 'new/',
+                 'marknsfw':            'api/marknsfw/',
                  'popular_reddits':     'reddits/popular/',
                  'read_message':        'api/read_message/',
                  'reddit_url':          '/',
@@ -87,6 +88,7 @@ class Config(object):  # pylint: disable-msg=R0903
                  'subscribe':           'api/subscribe/',
                  'undistinguish':       'api/distinguish/no/',
                  'unfriend':            'api/unfriend/',
+                 'unmarknsfw':          'api/unmarknsfw/',
                  'unread':              'message/unread/',
                  'unread_message':      'api/unread_message/',
                  'unsave':              'api/unsave/',
